Crate unb_server

Crate unb_server 

Re-exports

pub use rustls;

Modules

dynamic
webtransport

Structs

CancellationToken
Endpoint
EndpointSet
HandlerError
HandlerService
HealthStatus
HostConfig
Hosting
InsecureAcceptDeclaredPeerIdentities
LayerFn
Next
Node
NodeBuilder
NodeIdentity
OperationContract
ParentLink
PeerConnection
A cloneable handle to one verified direct peer identity.
PeerLayerFn
PeerNext
PeerRequest
Reply
Request
Scope
SelfSignedIdentity
ServerIdentity
State
States
Streaming
TcpTransport
TopologyConfig
UnbTopology
UnixHosting
VerifiedPeer
WebTransportConfig
Wire

Enums

ConnectError
A stable, cloneable failure category for initial connection establishment.
ConnectionStatus
The current state of a durable logical peer connection.
ContractSchema
Detail
DisconnectReason
Why a durable logical peer connection is currently disconnected.
DiscoverScope
ErrorCode
HostError
Operation
Origin
Pipe
ServiceBody
TcpSecurity
TransportKind
WsError

Traits

Destination
Handler
HandlerOutput
IntoBody
Layer
PeerLayer
SendExt

Functions

accept_unix
connect_unix
layer_fn
peer_layer_fn
validate_node_identifier

Type Aliases

EventStream