pub struct ClientPool { /* private fields */ }Expand description
Reuses native QUIC endpoints across sessions with the same certificate policy.
Implementations
Sourceimpl ClientPool
impl ClientPool
Sourcepub fn new() -> ClientPool
pub fn new() -> ClientPool
Creates an empty native WebTransport client pool.
Sourcepub async fn dial(
&self,
url: &str,
cert_hash: Option<[u8; 32]>,
) -> Result<(Pin<Box<dyn TransportPipe<Error = TransportError, Item = Result<Bytes, TransportError>> + Send>>, bool, Arc<ConnectionStreams>), TransportError>
pub async fn dial( &self, url: &str, cert_hash: Option<[u8; 32]>, ) -> Result<(Pin<Box<dyn TransportPipe<Error = TransportError, Item = Result<Bytes, TransportError>> + Send>>, bool, Arc<ConnectionStreams>), TransportError>
Opens a session while reusing the matching native QUIC endpoint.